@@ -522,6 +522,12 @@ extern void *__argp_input (__const struct argp *__restrict __argp,
 extern char *_argp_basename(char *name) __THROW;
 extern char *__argp_basename(char *name) __THROW;
 
+/* Getting the program name given an argp state */
+extern char *
+_argp_short_program_name(const struct argp_state *state) __THROW;
+extern char *
+__argp_short_program_name(const struct argp_state *state) __THROW;
+
 
 #ifdef __USE_EXTERN_INLINES
 
