@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.33 2000/11/15 16:37:04 nisse Exp $
+ * $Id: connection_commands.c,v 1.34 2000/11/26 23:25:50 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -37,13 +37,6 @@
 
 #include "connection_commands.c.x"
 
-/* ;;GABA:
-   (class
-     (name connection_remember_command)
-     (super command)
-     (vars
-       (connection object ssh_connection)))
-*/
 
 static void
 do_connection_remember(struct command *s,
