@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.68 2000/11/16 22:39:21 nisse Exp $ */
+ * $Id: io.h,v 1.70 2000/11/26 23:25:53 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -86,7 +86,6 @@ extern struct lsh_class io_backend_class;
        ; which seems kind of bogus.
        (e object exception_handler)
        
-       ;;(close_reason . int)
        ; User's close callback
        (close_callback object lsh_callback)
 
@@ -199,9 +198,9 @@ make_listen_value(struct lsh_fd *fd,
      (name io_exception)
      (super exception)
      (vars
-       ;; NULL if no fd was involved
+       ; NULL if no fd was involved
        (fd object lsh_fd)
-       ;; errno code, or zero if not available
+       ; errno code, or zero if not available
        (error . int))))
 */
 
@@ -218,9 +217,6 @@ extern const struct exception finish_io_exception;
 
 struct io_backend *
 make_io_backend(void);
-#if 0
-void init_backend(struct io_backend *b);
-#endif
 
 int io_iter(struct io_backend *b);
 void io_run(struct io_backend *b);
@@ -351,15 +347,6 @@ io_read_file(struct io_backend *backend,
 	     const char *fname, 
 	     struct exception_handler *e);
 
-#if 0
-struct lsh_fd *
-io_read_user_file(struct io_backend *backend,
-		  const char *fname,
-		  uid_t uid, int secret,
-		  const struct exception **x,
-		  struct exception_handler *e);
-#endif
-
 int
 lsh_make_pipe(int *fds);
 
