@@ -2,7 +2,7 @@
  *
  * main proxy program.
  *
- * $Id: lsh_proxy.c,v 1.18 2000/11/15 17:03:56 nisse Exp $ */
+ * $Id: lsh_proxy.c,v 1.20 2000/11/26 23:25:56 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -96,11 +96,6 @@ struct command_simple proxy_destination;
 #include <unistd.h>
 #endif
 
-#if 0
-/* Block size for stdout and stderr buffers */
-#define BLOCK_SIZE 32768
-#endif
-
 /* Option parsing */
 
 const char *argp_program_version
@@ -690,10 +685,10 @@ int main(int argc, char **argv)
 
   ALIST_SET(algorithms_server, 
 	    ATOM_DIFFIE_HELLMAN_GROUP1_SHA1,
-	    make_dh_server(make_dh1(&r->super)));
+	    &make_dh_server(make_dh1(&r->super))->super);
   ALIST_SET(algorithms_client, 
 	    ATOM_DIFFIE_HELLMAN_GROUP1_SHA1,
-	    make_dh_client(make_dh1(&r->super)));
+	    &make_dh_client(make_dh1(&r->super))->super);
   
   make_kexinit
     = make_simple_kexinit(&r->super,
