@@ -1,6 +1,6 @@
 /* lsh_types.h
  *
- * $Id: lsh_types.h,v 1.40 2000/05/07 14:42:28 nisse Exp $ */
+ * $Id: lsh_types.h,v 1.41 2000/11/20 20:09:46 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -129,6 +129,12 @@ do {						\
   (p)[3] = (i) & 0xff;				\
 } while(0)
 
+/* Same, for 24-bit quantities */
+#define READ_UINT24(p)				\
+((((UINT32) (p)[0]) << 24)			\
+ | (((UINT32) (p)[1]) << 16)			\
+ | ((UINT32) (p)[2]))
+
 /* Same, for 16-bit quantities */
 #define READ_UINT16(p)				\
 ((((UINT32) (p)[0]) << 16)			\
