@@ -1,6 +1,6 @@
 /* rsa.c
  *
- * $Id: rsa.c,v 1.11 2000/10/17 23:48:44 nisse Exp $
+ * $Id: rsa.c,v 1.12 2000/11/26 23:25:59 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -475,12 +475,6 @@ do_rsa_sign_spki(struct signer *s,
   rsa_compute_root(self, m, m);
 
   signature = encode_rsa_sig_val(m);
-
-#if 0
-  /* Build signature */
-  signature = sexp_l(4, SA(SIGNATURE), hash, principal,
-		     sexp_un(m), -1);
-#endif
   
   mpz_clear(m);
   return signature;
