@@ -1,6 +1,6 @@
 /* server_userauth.h
  *
- * $Id: server_userauth.h,v 1.14 2000/10/09 23:41:23 nisse Exp $
+ * $Id: server_userauth.h,v 1.15 2000/10/15 20:42:23 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -53,7 +53,8 @@
 #define USER_LOOKUP(db, n, f) ((db)->lookup((db), (n), (f)))
 
 struct user_db *
-make_unix_user_db(struct io_backend *backend, const char *pw_helper, int allow_root);
+make_unix_user_db(struct io_backend *backend, struct reap *reaper,
+		  const char *pw_helper, int allow_root);
 
 /* GABA:
    (class
