@@ -2,7 +2,7 @@
  *
  * SPKI interface
  *
- * $Id: spki_commands.c,v 1.15 2000/11/26 23:26:02 nisse Exp $ */
+ * $Id: spki_commands.c,v 1.16 2000/12/11 21:37:42 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -493,6 +493,7 @@ DEFINE_COMMAND_SIMPLE(spki_return_userkeys, a)
 
 struct command *
 make_spki_read_userkeys(struct alist *algorithms,
+			struct alist *signature_algorithms,
 			struct interact *tty)
 {
   struct command *decrypt;
@@ -515,7 +516,7 @@ make_spki_read_userkeys(struct alist *algorithms,
 
   {
     CAST_SUBTYPE(command, res,
-		 spki_read_userkeys(algorithms,
+		 spki_read_userkeys(signature_algorithms,
 				    decrypt));
 
     return res;
