@@ -1,6 +1,6 @@
 /* tcpforward.c
  *
- * $Id: tcpforward.c,v 1.54 2000/10/07 00:00:30 nisse Exp $
+ * $Id: tcpforward.c,v 1.56 2000/11/26 23:26:03 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -282,9 +282,7 @@ make_open_forwarded_tcpip_continuation(struct ssh_connection *connection,
 static void
 do_channel_open_direct_tcpip(struct channel_open *s,
 			     struct ssh_connection *connection,
-			     UINT32 channel_type UNUSED,
-			     UINT32 send_window_size UNUSED,
-			     UINT32 send_max_packet UNUSED,
+			     struct channel_open_info *info UNUSED,
 			     struct simple_buffer *args,
 			     struct command_continuation *c,
 			     struct exception_handler *e)
@@ -439,11 +437,11 @@ make_tcpip_forward_request_exc(struct ssh_connection *connection,
      (name tcpip_forward_request)
      (super global_request)
      (vars
-       ;; The callback is invoked for each request, with the port as
-       ;; argument. If successful, it should return the fd object
-       ;; associated with the listening port. It need not remember the port;
-       ;; the continuation installed by do_tcpip_forward_request()
-       ;; takes care of that.
+       ; The callback is invoked for each request, with the port as
+       ; argument. If successful, it should return the fd object
+       ; associated with the listening port. It need not remember the port;
+       ; the continuation installed by do_tcpip_forward_request()
+       ; takes care of that.
        (callback object command)))
 */
 
@@ -583,9 +581,7 @@ struct global_request tcpip_cancel_forward =
 static void
 do_channel_open_forwarded_tcpip(struct channel_open *s UNUSED,
 				struct ssh_connection *connection,
-				UINT32 channel_type UNUSED,
-				UINT32 send_window_size UNUSED,
-				UINT32 send_max_packet UNUSED,
+				struct channel_open_info *info UNUSED,
 				struct simple_buffer *args,
 				struct command_continuation *c,
 				struct exception_handler *e)
